<?php
/**
 * Plugin Name: Animated Lottie icons for Elementor
 * Plugin URI:  http://www.animated-svg.com/
 * Description: Animated Lottie icon library for Elementor page builder
 * Version:     2.2.0
 * Requires at least: 4.7
 * Tested up to: 5.8.1
 * Author:      animatedsvg
 * Author URI:  https://www.animated-svg.com/
 * Text Domain: animatesvg
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}


/* PLUGIN URL */
define( 'ASVG_URL', plugins_url( '/', __FILE__ ) );

/* PLUGIN PATH */
define( 'ASVG_PATH', plugin_dir_path( __FILE__ ) );
define( 'ASVG_ASTS', ASVG_URL . 'assets' );
define( 'ASVG_CSS', ASVG_ASTS . '/css' );
define( 'ASVG_JS', ASVG_ASTS . '/js' );
define( 'ASVG_IMGS', ASVG_ASTS . '/images' );
define( 'ASVG_INC', ASVG_PATH . 'inc' );
define( 'ASVG_ELEMENTOR', ASVG_INC . '/elementor-widgets' );
define( 'ASVG_PLUGIN_MENU', 'asvg-menu' );

	add_action('elementor/editor/before_enqueue_scripts', function() {
	wp_enqueue_style( 'asvg-editor', ASVG_CSS.'/editor.css');
	wp_enqueue_style( 'asvg', ASVG_CSS.'/asvg.css');

	});

/**
 * Main Elementor Test Extension Class
 *
 *
 * @since 1.0.0
 */


if( !class_exists('Elementor_Animated_Svg') ){
	final class Elementor_Animated_Svg {


		/**
		 * Minimum Elementor Version
		 *
		 * @since 1.0.0
		 *
		 * @var string Minimum Elementor version required to run the plugin.
		 */
		const MINIMUM_ELEMENTOR_VERSION = '2.0.0';

		/**
		 * Minimum PHP Version
		 *
		 * @since 1.0.0
		 *
		 * @var string Minimum PHP version required to run the plugin.
		 */
		const MINIMUM_PHP_VERSION = '5.6';


		/**
		 * Instance
		 *
		 * @since 1.0.0
		 *
		 * @access private
		 * @static
		 *
		 * @var Elementor_Animated_Svg The single instance of the class.
		 */
		private static $_instance = null;

		/**
		 * Instance
		 *
		 * Ensures only one instance of the class is loaded or can be loaded.
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 * @static
		 *
		 * @return Elementor_Animated_Svg An instance of the class.
		 */
		public static function instance() {

			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;

		}

		/**
		 * Constructor
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function __construct() {

			// include files
			$this->init_files();
			// init hook
			add_action( 'init', [ $this, 'i18n' ] );
			add_action( 'plugins_loaded', [ $this, 'init' ] );
			// elementor categories
			add_action( 'elementor/elements/categories_registered', [$this, 'widget_categories'],99 );

			add_action('wp_enqueue_scripts',[$this,'load_scripts']);

		}


		/**
		 * Load Textdomain
		 *
		 * Load plugin localization files.
		 *
		 * Fired by `init` action hook.
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function i18n() {

			load_plugin_textdomain( 'animatesvg', false, ASVG_PATH . 'languages' );

		}

		/**
		 *Files Includes
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function init_files(){
			if( file_exists( ASVG_INC . '/helper-function.php' ) ){
				require_once( ASVG_INC . '/helper-function.php' );
				require_once( ASVG_INC . '/options.php' );
			}

		}

		/**
		 * Initialize the plugin
		 *
		 *
		 * Fired by `plugins_loaded` action hook.
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function init() {

			// Check if Elementor installed and activated
			if ( ! did_action( 'elementor/loaded' ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
				return;
			}

			// Check for required Elementor version
			if ( ! version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
				return;
			}

			// Check for required PHP version
			if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
				return;
			}

			// Add Plugin actions
			add_action( 'elementor/widgets/widgets_registered', [ $this, 'init_widgets' ] );
		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have Elementor installed or activated.
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function admin_notice_missing_main_plugin() {

			if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

			$message = sprintf(
				/* translators: 1: Plugin name 2: Elementor */
				esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'animatesvg' ),
				'<strong>' . esc_html__( 'Animated SVG for Elementor Page Builder', 'animatesvg' ) . '</strong>',
				'<strong>' . esc_html__( 'Elementor', 'animatesvg' ) . '</strong>'
			);

			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have a minimum required Elementor version.
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function admin_notice_minimum_elementor_version() {

			if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

			$message = sprintf(
				/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
				esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'animatesvg' ),
				'<strong>' . esc_html__( 'Animated SVG for Elementor Page Builder', 'animatesvg' ) . '</strong>',
				'<strong>' . esc_html__( 'Elementor', 'animatesvg' ) . '</strong>',
				 self::MINIMUM_ELEMENTOR_VERSION
			);

			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

		}

		/**
		 * Admin notice
		 *
		 * Warning when the site doesn't have a minimum required PHP version.
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function admin_notice_minimum_php_version() {

			if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

			$message = sprintf(
				/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
				esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'animatesvg' ),
				'<strong>' . esc_html__( 'Animated SVG for Elementor Page Builder', 'animatesvg' ) . '</strong>',
				'<strong>' . esc_html__( 'PHP', 'animatesvg' ) . '</strong>',
				 self::MINIMUM_PHP_VERSION
			);

			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

		}
		

		/**
		 * Scripts Load
		 *
		 * @since   1.0.0
		 */
		public function load_scripts(){
			$action_elementor = isset($_GET['elementor-preview']) ? true : false;
            wp_enqueue_style( 'asvg-styles', ASVG_CSS . '/styles.css' );
			wp_enqueue_style( 'animations', ASVG_CSS . '/animations.css' );
			wp_register_style( 'frontend', ASVG_CSS . '/frontend.min.css' );
			wp_register_script( 'lottie_asvg', ASVG_JS . '/lottie.min.js', array( 'jquery' ) );
			wp_register_script( 'asvg_lottie_icons', ASVG_JS . '/asvg_lottie_icons.js', array( 'jquery' ) );

		}

        public function widget_categories( $elements_manager )
        {
            $elements_manager->add_category( 'animated-svg', [
                'title' => __( 'ASVG', 'asvg' ),
                'icon'  => 'asvg icon-icons',
            ] );
        }
		/**
		 * Init Widgets
		 *
		 * Include widgets files and register them
		 *
		 * @since 1.0.0
		 *
		 * @access public
		 */
		public function init_widgets(){

			// Include Widget files
				require_once( ASVG_ELEMENTOR . '/asvg-lottie-free.php' );
				require_once( ASVG_ELEMENTOR . '/upload-free.php' );
		}


	} // end Class
} // end condition

		function asvg_action_links($links, $file) {
			static $this_plugin;
		 
			if (!$this_plugin) {
				$this_plugin = plugin_basename(__FILE__);
			}
		 
			if ($file == $this_plugin) {
		 
				$plugin_links[] = '<a href="../wp-admin/admin.php?page=asvg-menu">View content</a>';
				
				$plugin_links[] = '<a href="https://animated-svg.com/" target="_blank"><b><alt="Get all 1000+ icons, 260+ Lottie animations, the animated text and flip box widgets and more..." title="Get all 1000+ icons, 260+ Lottie animations, the animated text and flip box widgets and more..."><span style="color: #f2295b;">GO PRO</span></b></a>';
						
				
				foreach($plugin_links as $link) {
					array_unshift($links, $link);
				}
			}

			return $links;
		}
		add_filter('plugin_action_links', 'asvg_action_links', 100, 110);


		if( class_exists('Elementor_Animated_Svg') ){
			Elementor_Animated_Svg::instance();
		}