<?php
namespace Elementor;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

class ASVGLottie_FREE extends Widget_Base {

	public function get_name() {
		return 'asvg_lottie_free';
	}

	public function get_title() {
		return esc_html__('Animated Icons', 'asvg');
	}

	public function get_icon() {
		 return 'asvg icon-icons';
	}
	public function get_categories() {
        return array('animated-svg');
    }

	public function get_script_depends() {
		return ['lottie_asvg', 'asvg_lottie_icons'];
	}

    public function get_keywords() {
        return [ 'icons', 'animation', 'asvg', 'lottie', ];
    }

	protected function _register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Lottie Animation', 'asvg' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'select_svg_option',
			[
				'label' => __( 'Select source', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'lottie_icons_bas',
				'options' => [
					'lottie_icons_bas'  => __( 'Basic icons', 'asvg' ),
					'lottie_icons_arr'  => __( 'Arrow icons', 'asvg' ),
					'lottie_icons_cta2'  => __( 'Call to action icons', 'asvg' ),
					'lottie_icons_fin2'  => __( 'Financial icons2', 'asvg' ),
					'lottie_icons_foo'  => __( 'Food icons', 'asvg' ),
					'lottie_icons_hol'  => __( 'Holiday & event icons', 'asvg' ),
					'lottie_icons_med'  => __( 'Medical icons', 'asvg' ),
					'lottie_icons_mus'  => __( 'Music & sound icons', 'asvg' ),
					'lottie_icons_obj'  => __( 'Object icons', 'asvg' ),
					'lottie_icons_off'  => __( 'Office & document icons', 'asvg' ),
					'lottie_icons_ret2'  => __( 'Retail icons', 'asvg' ),
					'lottie_icons_smi'  => __( 'Smileys & emoticons', 'asvg' ),
					'lottie_icons_sym'  => __( 'Symbols & signs', 'asvg' ),
					'lottie_icons_tec'  => __( 'Technology icons', 'asvg' ),
					'lottie_icons_txt2'  => __( 'Text & numbers', 'asvg' ),
					'lottie_icons_tra'  => __( 'Travel icons', 'asvg' ),
					'lottie_icons_wea'  => __( 'Weather & nature icons', 'asvg' ),
					'lottie_icons_bas2'  => __( 'Basic icons &#40;spinning&#41;', 'asvg' ),
				],
			]
		);

		$this->add_control(
			'lottie_icons_bas',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'bas_alarm.json',
				'options' => asvg_bas_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_bas',
				],
			]
		);
		$this->add_control(
			'lottie_icons_bas2',
			[
				'label' => __( 'Select animation', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'bas_alarm.json',
				'options' => asvg_bas_spin_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_bas2',
				],
			]
		);

		$this->add_control(
			'lottie_icons_arr',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'arrow_boxed_down.json',
				'options' => asvg_arr_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_arr',
				],
			]
		);

		$this->add_control(
			'lottie_icons_cta2',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'cta_click_button_left.json',
				'options' => asvg_cta2_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_cta2',
				],
			]
		);

		$this->add_control(
			'lottie_icons_fin2',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'finance_chart_column.json',
				'options' => asvg_fin_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_fin2',
				],
			]
		);

		$this->add_control(
			'lottie_icons_foo',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'food_apple.json',
				'options' => asvg_foo_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_foo',
				],
			]
		);

		$this->add_control(
			'lottie_icons_hol',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'christmas_bauble_abstract.json',
				'options' => asvg_hol_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_hol',
				],
			]
		);

		$this->add_control(
			'lottie_icons_med',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'medical_cross.json',
				'options' => asvg_med_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_med',
				],
			]
		);

		$this->add_control(
			'lottie_icons_mus',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'music_button_begin.json',
				'options' => asvg_mus_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_mus',
				],
			]
		);

		$this->add_control(
			'lottie_icons_obj',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'object_anchor.json',
				'options' => asvg_obj_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_obj',
				],
			]
		);

		$this->add_control(
			'lottie_icons_off',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'office_book.json',
				'options' => asvg_off_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_off',
				],
			]
		);

		$this->add_control(
			'lottie_icons_ret2',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'ret_badge_50_off.json',
				'options' => asvg_ret2_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_ret2',
				],
			]
		);

		$this->add_control(
			'lottie_icons_smi',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'smiley_doodle_indiff.json',
				'options' => asvg_smi_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_smi',
				],
			]
		);

		$this->add_control(
			'lottie_icons_sym',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'symbol_minus.json',
				'options' => asvg_sym_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_sym',
				],
			]
		);

		$this->add_control(
			'lottie_icons_tec',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'tech_browser.json',
				'options' => asvg_tec_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_tec',
				],
			]
		);

		$this->add_control(
			'lottie_icons_txt2',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'text_n0.json',
				'options' => asvg_txt2_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_txt2',
				],
			]
		);

		$this->add_control(
			'lottie_icons_tra',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'travel_airplane.json',
				'options' => asvg_tra_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_tra',
				],
			]
		);

		$this->add_control(
			'lottie_icons_wea',
			[
				'label' => __( '<alt="◎ icon has secondary stroke color,  ◉ icon has fill color" title="◎ icon has secondary stroke color,  ◉ icon has fill color">Select animation <sup><i class="fa fa-question-circle"></i>', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'bas_cloud.json',
				'options' => asvg_wea_lottie_list(),
				'condition' => [
					'select_svg_option' => 'lottie_icons_wea',
				],
			]
		);

		$this->add_control(
			'action',
			[
				'label' => __( 'Play setting', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'hover_auto',
				'options' => [
					'autoplay'			=> __( 'Autoplay', 'asvg' ),
					'hover_auto'		=> __( 'Autoplay + on hover', 'asvg' ),
					'click_auto'		=> __( 'Autoplay + on click', 'asvg' ),
					'viewport'			=> __( 'Play in viewport', 'asvg' ),
					'hover'				=> __( 'Play in viewport + on hover', 'asvg' ),
					'click'   			=> __( 'Play in viewport + on click', 'asvg' ),
					'parallax_effect'	=> __( 'Play on scroll', 'asvg' ),
				],
				'condition' => [
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]
		);

		$this->add_control(
			'mode',
			[
				'label' => __( 'Play mode', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'del',
				'options' => [
					'del'		=> __( 'Delayed', 'asvg' ),
					'one'		=> __( 'One by one', 'asvg' ),
					'sync'		=> __( 'Synchronized', 'asvg' ),
					],
				'condition' => [
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea' ]
				],
			]
		);

		$this->add_control(
			'type_delay',
			[
				'label' => __( '<span style="font-size:11px">Delay for each path, all end at the same time.</span>', 'asvg' ),
				'type' => Controls_Manager::RAW_HTML,
				'condition' => [
					'mode' => 'del',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea']
				],
			]
		);

		$this->add_control(
			'type_one',
			[
				'label' => __( '<span style="font-size:11px">Each path is drawn on one at a time.</span>', 'asvg' ),
				'type' => Controls_Manager::RAW_HTML,
				'condition' => [
					'mode' => 'one',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea']
				],
			]
		);

		$this->add_control(
			'type_sync',
			[
				'label' => __( '<span style="font-size:11px">All paths start and end at the same time.</span>', 'asvg' ),
				'type' => Controls_Manager::RAW_HTML,
				'condition' => [
					'mode' => 'sync',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea']
				],
			]
		);

		$this->add_control(
			'loop',
			[
				'label' => esc_html__( 'Continuous loop', 'asvg' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'OFF', 'asvg' ),
				'label_off' => esc_html__( 'ON', 'asvg' ),
				'return_value' => 'true',
				'default' => 'true',
				'condition' => [
				'action' => ['autoplay', 'hover', 'hover_auto', 'click', 'click_auto', 'viewport'],
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]
		);

		$this->add_control(
			'loop_counter',
			[
				'label' => esc_html__( 'Number of times to play (1-99)', 'asvg' ),
				'type' => Controls_Manager::NUMBER,
				'default' => '1',
				'min' => 1,
				'max' => 99,
				'step' => 1,
				'condition' => [
					'action' => ['autoplay', 'hover', 'hover_auto', 'click', 'click_auto', 'viewport'],
					'loop' => 'true',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]
		);

		$this->add_control(
			'scrollbased',
			[
				'label' => __( 'Scroll settings', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'custom',
				'options' => [
					'custom' => __( 'Viewport', 'asvg' ),
					'document'  => __( 'Entire page', 'asvg' ),
				],
				'description' => __( '<span style="font-size: 11px; font-style: normal; line-height: 1.4">In "Viewport" mode, you need to set duration and offset for animation. If you select "Entire page", animation will be based on whole page\'s height.</span>', 'asvg' ),
				'condition' => [
					'action' => 'parallax_effect',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]
		);

		$this->add_control(
			'section_duration',
			[
				'label' => __( 'Duration', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 50,
						'max' => 2000,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 400,
				],
				'condition' => [
					'action' => 'parallax_effect',
					'scrollbased' => 'custom',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]
		);

		$this->add_control(
			'section_offset',
			[
				'label' => __( 'Offset', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => -1000,
						'max' => 1000,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 400,
				],
				'condition' => [
					'action' => 'parallax_effect',
					'scrollbased' => 'custom',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]
		);

		$this->add_control(
			'speed',
			[
				'label' => esc_html__( 'Play speed (0.1- 5)', 'asvg' ),
				'type'  => Controls_Manager::SLIDER,
				'separator' => 'before',
				'range' => [
					'px' => [
						'min' => 0.1,
						'max' => 5,
                        'step' => 0.1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1,
				],
				'condition' => [
					'action' => ['autoplay', 'hover_auto','click_auto', 'viewport', 'hover', 'click'],
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]
		);

		$this->add_control(
			'custom_time',
			[
				'label' => esc_html__( 'Custom animation timing', 'asvg' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'ON', 'asvg' ),
				'label_off' => esc_html__( 'OFF', 'asvg' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
					'action' => 'parallax_effect',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']

				],
			]
		);
		$this->add_control(
			'start_time',
			[
				'label' => esc_html__( 'Start time (frame no.)', 'asvg' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 5000,
				'step' => 10,
				'default' => '1',
				'condition' => [
					'action' =>  'parallax_effect',
					'custom_time' => 'yes',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']

				],
			]
		);

		$this->add_control(
			'end_time',
			[
				'label' => esc_html__( 'End time (frame no.)', 'asvg' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 5000,
				'step' => 10,
				'default' => '100',
				'condition' => [
					'action' => 'parallax_effect',
					'custom_time' => 'yes',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]
		);

		$this->add_control(
			'add_link',
			[
				'label' => esc_html__( 'Add link', 'asvg' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'yes', 'asvg' ),
				'label_off' => esc_html__( 'no', 'asvg' ),
				'default' => 'no',
				'separator' => 'before',
				'condition' => [
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]
		);

		$this->add_control(
			'link',
			[
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'asvg' ),
				'show_external' => true,
				'default' => [
					'url' => '',
				],
				'condition' => [
					'add_link' => 'yes',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]
		);

		$this->add_control(
			'link_delay_switch',
			[
				'label' => __( 'Add delay when clicked?', 'asvg' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'asvg' ),
				'label_off' => __( 'No', 'asvg' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'action' => ['click', 'click_auto', 'hover', 'hover_auto'],
					'add_link' => 'yes',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]
          );

		$this->add_control(
			'link_delay',
			[
				'label' => esc_html__( 'Click delay (ms)', 'asvg' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 100,
						'max' => 10000,
                        'step' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1000,
				],
				'condition' => [
					'action' => ['click', 'click_auto', 'hover', 'hover_auto'],
					'add_link' => 'yes',
					'link_delay_switch' => 'yes',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]
		);

		$this->add_control(
			'link_delay',
			[
				'label' => esc_html__( 'Click delay (in ms)', 'asvg' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 100,
						'max' => 10000,
                        'step' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1000,
				],
				'condition' => [
					'link' => 'yes',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
				'frontend_available' => true,
			]
		);

		$this->add_control(
			'link_delay_blank',
			[
				'label' => __( 'Open link in same browser tab?', 'asvg' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'asvg' ),
				'label_off' => __( 'No', 'asvg' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
					'action' => ['click', 'click_auto', 'hover', 'hover_auto'],
					'add_link' => 'yes',
					'link_delay_switch' => 'yes',
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]

          );

		$this->end_controls_section();



/*STYLE*/

		$this->start_controls_section(
			'section_lotties_option',
			[
				'label' => esc_html__( 'Lottie Style', 'asvg' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'select_svg_option' => ['lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				],
			]
		);

		$this->add_responsive_control(
			'content_align',
			[
				'label' => esc_html__( 'Alignment', 'asvg' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'asvg' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'asvg' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'asvg' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'center',
				'prefix_ class' => 'text-%s',
			]
		);

		$this->add_responsive_control(
			'max_width',
			[
				'label' => esc_html__( 'Maximum width', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => '%',
					'size' => 50,
				],
				'render_type' => 'ui',
				'selectors' => [
					'{{WRAPPER}} .asvg-lotties-animation-wrapper' => 'max-width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'lottie_margin',
			[
				'label' => __( 'Margin (in pixels)', 'asvg' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px'],
				'selectors' => [
					'{{WRAPPER}} .asvg-lotties-animation-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'lottie_padding',
			[
				'label' => __( 'Padding (in pixels)', 'asvg' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px'],
				'selectors' => [
					'{{WRAPPER}} svg' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'after',
			]
		);

		$this->add_control(
			'space',
			[
				'label' => __( '<br>Styling options<br>', 'asvg' ),
				'type' => Controls_Manager::RAW_HTML,

			]
		);

		$this->start_controls_tabs( 'image_effects' );

/* Normal */

		$this->start_controls_tab( 'normal_lottie',
			array(
				'label' => __( 'Normal', 'asvg' ),
			)
		);

		$this->add_control(
			'color_main',
			[
				'label' => __( 'Stroke color 1', 'asvg' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#6942b7',
			]
		);

		$this->add_control(
			'color_accent',
			[
				'label' => __( 'Stroke color 2 &#40;if available&#41;', 'asvg' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#f2295b',
			]
		);
		$this->add_control(
            'stroke',
			[
				'label' => esc_html__( 'Stroke width', 'asvg' ),
				'type' => Controls_Manager::NUMBER,
				'label_block' => false,
				'min' => 1,
				'max' => 30,
				'step' => 1,
				'default' => 18,
                'dynamic' => [
                    'active' => false,
                  ],
			]
		);

		$this->add_control(
			'color_fill',
			[
				'label' => __( '<alt="Set to transparent to hide fill color, like #FFFFFF00" title="Set to transparent to hide fill color, like #FFFFFF00">Fill color &#40;if available&#41; <sup><i class="fa fa-question-circle"></i></sup>', 'asvg' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#dcdcdc',
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'color_bkg',
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .asvg-lotties-animation-wrapper',
			]
		);

		$this->add_control(
			'rotate_lottie',
			[
				'label' => __( '<br>Rotation', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'separator' => 'before',
				'default' => [
					'size' => 0,
					'unit' => 'deg',
				],
				'selectors' => [
					'{{WRAPPER}} .asvg-lotties-animation-wrapper' => 'transform: rotate({{SIZE}}{{UNIT}});',

			],
			]
		);

		$this->add_control(
			'opacity_lottie',
			array(
				'label' => __( 'Opacity', 'asvg' ),
				'type'  => \Elementor\Controls_Manager::SLIDER,
				'range' => array(
					'px'  => array(
						'max'   => 1,
						'min'   => 0.10,
						'step'  => 0.01,
					),
				),
				'default' => [
					'size' => 1,
				],
				'selectors' => array(
					'{{WRAPPER}} .asvg-lotties-animation-wrapper' => 'opacity: {{SIZE}};',
				),
			)
		);

		$this->add_group_control(
			\Elementor\Group_Control_Css_Filter::get_type(),
			array(
				'name' => 'css_filters_lottie',
				'selector' => '{{WRAPPER}} .asvg-lotties-animation-wrapper',
			)
		);

		$this->add_control(
      		'shadow_add',
			[
                'label' => __( 'Shadow', 'asvg' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'asvg' ),
				'label_off' => __( 'No', 'asvg' ),
				'return_value' => 'yes',
				'default' => 'no',
				'frontend_available' => true,
			]
        );

		$this->add_control(
      		'shadow_x',
			 [
				'label' => __( 'Offset X', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => -50,
						'max' => 50,
						'step' => 1,
					],
					'em' => [
                        'min' => -5,
						'max' => 5,
						'step' => 0.1,
					],
                ],
                'default' => [
					'unit' => 'px',
					'size' => 2,
				],
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} svg' => 'filter: drop-shadow({{SIZE}}{{UNIT}} {{shadow_y.SIZE}}{{shadow_y.UNIT}} {{shadow_blur.SIZE}}{{shadow_blur.UNIT}} {{shadow_color.VALUE}});',
                ],
                'condition' => [
					'shadow_add' => 'yes',
				],
			]
        );

		$this->add_control(
			'shadow_y',
            [
				'label' => __( 'Offset Y', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => -50,
						'max' => 50,
						'step' => 1,
					],
					'em' => [
                        'min' => -5,
						'max' => 5,
						'step' => 0.1,
					],
                ],
                'default' => [
					'unit' => 'px',
					'size' => 0,
				],
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} svg' => 'filter: drop-shadow({{shadow_x.SIZE}}{{shadow_x.UNIT}} {{SIZE}}{{UNIT}} {{shadow_blur.SIZE}}{{shadow_blur.UNIT}} {{shadow_color.VALUE}});',
                ],
                'condition' => [
					'shadow_add' => 'yes',
				],
			]
        );

		$this->add_control(
            'shadow_blur',
            [
				'label' => __( 'Blur', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
						'step' => 1,
					],
					'em' => [
						'max' => 10,
						'step' => 0.1,
					],
                ],
                'default' => [
					'unit' => 'px',
					'size' => 0,
				],
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} svg' => 'filter: drop-shadow({{shadow_x.SIZE}}{{shadow_x.UNIT}} {{shadow_y.SIZE}}{{shadow_y.UNIT}} {{SIZE}}{{UNIT}} {{shadow_color.VALUE}});',
                ],
                'condition' => [
					'shadow_add' => 'yes',
				],
			]
        );

		$this->add_control(
 			'shadow_color',
			[
				'label' => __( 'Shadow color', 'asvg' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#0000005E',
				'selectors' => [
					'{{WRAPPER}} svg' => 'filter: drop-shadow({{shadow_x.SIZE}}{{shadow_x.UNIT}} {{shadow_y.SIZE}}{{shadow_y.UNIT}} {{shadow_blur.SIZE}}{{shadow_blur.UNIT}} {{VALUE}});',
                ],
                'condition' => [
					'shadow_add' => 'yes',
				],
			]
		);

		$this->add_control(
      		'add_border_lottie',
      			[
        		'label'     => __( 'Border', 'asvg' ),
        		'type'      => Controls_Manager::SWITCHER,
				'label_on' => __( 'yes', 'your-plugin' ),
				'label_off' => __( 'no', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
      			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'lottie_border',
				'selector' => '{{WRAPPER}} .asvg-lotties-animation-wrapper',
				'condition' => [
				'add_border_lottie' => 'yes',
				],
			]
		);

		$this->add_responsive_control(
			'border_radius_lottie',
					[
				'render_type' => 'ui',
				'type' 			=> Controls_Manager::DIMENSIONS,
				'label' 		=> __( 'Border Radius', 'asvg' ),
				'size_units' 	=> [ 'px' ],
				'condition' => [
				'add_border_lottie' => 'yes',
				],
				'selectors' => [
					'{{WRAPPER}} .asvg-lotties-animation-wrapper'  => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				]
				);


		$this->add_control(
			'continuous_animation',
			[
				'label' => __( 'Continuous animation',  'asvg' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'asvg' ),
				'label_off'    => esc_html__( 'No', 'asvg' ),
				'render_type'  => 'template',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'animation_effect',
			[
				'label' => __( 'Animation effect', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'tossing',
				'options' => [
					'pulse-asvg'  => __( 'Pulse', 'asvg' ),
					'heartbeat'  => __( 'Heartbeat', 'asvg' ),
					'floating'  => __( 'Floating', 'asvg' ),
					'flip-horizontal-top'  => __( 'Flip', 'asvg' ),
					'tossing'  => __( 'Tossing', 'asvg' ),
					'rotate-continue'  => __( 'Rotating', 'asvg' ),
					'rotate-center'  => __( 'Rotate/Pause CCW', 'asvg' ),
				],
				'condition' => [
				'continuous_animation' => 'yes',
				],
			]
		);

		$this->end_controls_tab();

/* Hover */

		$this->start_controls_tab( 'hover_lottie',
			array(
				'label' => __( 'Hover', 'asvg' ),
			)
		);

		$this->add_control(
			'color_main_hov',
			[
				'label' => __( 'Stroke color 1', 'asvg' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#f2295b',
			]
		);

		$this->add_control(
			'color_accent_hov',
			[
				'label' => __( 'Stroke color 2 &#40;if available&#41;', 'asvg' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#6942b7',
			]
		);

		$this->add_control(
            'stroke_hov',
			[
				'label' => esc_html__( 'Stroke width', 'asvg' ),
				'type' => Controls_Manager::NUMBER,
				'label_block' => false,
				'min' => 1,
				'max' => 30,
				'step' => 1,
				'default' => 18,
                'dynamic' => [
                    'active' => false,
                  ],
			]
		);

		$this->add_control(
			'color_fill_hov',
			[
				'label' => __( '<alt="Set to transparent to hide fill color, like #FFFFFF00" title="Set to transparent to hide fill color, like #FFFFFF00">Fill color &#40;if available&#41; <sup><i class="fa fa-question-circle"></i></sup>', 'asvg' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#ededed',
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'color_bkg_hov',
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .asvg-lotties-animation-wrapper:hover',
			]
		);

		$this->add_control(
			'rotate_lottie_hov',
			[
				'label' => __( '<br>Rotation', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'separator' => 'before',
				'default' => [
					'size' => 0,
					'unit' => 'deg',
				],
				'selectors' => [
					'{{WRAPPER}} .asvg-lotties-animation-wrapper:hover' => 'transform: rotate({{SIZE}}{{UNIT}});',
				],
			]
		);

		$this->add_control(
			'opacity_lottie_hover',
			array(
				'label' => __( 'Opacity', 'asvg' ),
				'type'  => \Elementor\Controls_Manager::SLIDER,
				'range' => array(
					'px'  => array(
						'max'   => 1,
						'min'   => 0.10,
						'step'  => 0.01,
					),
				),
				'default' => [
					'size' => 1,
				],
				'selectors' => array(
					'{{WRAPPER}} .asvg-lotties-animation-wrapper:hover' => 'opacity: {{SIZE}};',
				),
			)
		);

		$this->add_control(
			'hover_transition_lottie',
			array(
				'label' => __( 'Transition duration', 'asvg' ),
				'type'  => \Elementor\Controls_Manager::SLIDER,
				'range' => array(
					'px'  => array(
						'max'   => 10,
						'step'  => 0.1,
					),
				),
				'default' => [
					'size' => 3,
				],
			)
		);

		$this->add_group_control(
			\Elementor\Group_Control_Css_Filter::get_type(),
			array(
				'name' => 'css_filters_lottie_hover',
				'selector' => '{{WRAPPER}} .asvg-lotties-animation-wrapper:hover',
			)
		);

		$this->add_control(
      		'shadow_add_hover',
			[
                'label' => __( 'Shadow', 'asvg' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'asvg' ),
				'label_off' => __( 'No', 'asvg' ),
				'return_value' => 'yes',
				'default' => 'no',
				'frontend_available' => true,
			]
        );

		$this->add_control(
      		'shadow_x_hover',
			 [
				'label' => __( 'Offset X', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => -50,
						'max' => 50,
						'step' => 1,
					],
					'em' => [
                        'min' => -5,
						'max' => 5,
						'step' => 0.1,
					],
                ],
                'default' => [
					'unit' => 'px',
					'size' => 2,
				],
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} svg:hover' => 'filter: drop-shadow({{SIZE}}{{UNIT}} {{shadow_y_hover.SIZE}}{{shadow_y_hover.UNIT}} {{shadow_blur_hover.SIZE}}{{shadow_blur_hover.UNIT}} {{shadow_color_hover.VALUE}});',
                ],
                'condition' => [
					'shadow_add_hover' => 'yes',
				],
			]
        );

		$this->add_control(
			'shadow_y_hover',
            [
				'label' => __( 'Offset Y', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => -50,
						'max' => 50,
						'step' => 1,
					],
					'em' => [
                        'min' => -5,
						'max' => 5,
						'step' => 0.1,
					],
                ],
                'default' => [
					'unit' => 'px',
					'size' => 2,
				],
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} svg:hover' => 'filter: drop-shadow({{shadow_x_hover.SIZE}}{{shadow_x_hover.UNIT}} {{SIZE}}{{UNIT}} {{shadow_blur_hover.SIZE}}{{shadow_blur_hover.UNIT}} {{shadow_color_hover.VALUE}});',
                ],
                'condition' => [
					'shadow_add_hover' => 'yes',
				],
			]
        );

		$this->add_control(
            'shadow_blur_hover',
            [
				'label' => __( 'Blur', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
						'step' => 1,
					],
					'em' => [
						'max' => 10,
						'step' => 0.1,
					],
                ],
                'default' => [
					'unit' => 'px',
					'size' => 2,
				],
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} svg:hover' => 'filter: drop-shadow({{shadow_x_hover.SIZE}}{{shadow_x_hover.UNIT}} {{shadow_y_hover.SIZE}}{{shadow_y_hover.UNIT}} {{SIZE}}{{UNIT}} {{shadow_color_hover.VALUE}});',
                ],
                'condition' => [
					'shadow_add_hover' => 'yes',
				],
			]
        );

		$this->add_control(
 			'shadow_color_hover',
			[
				'label' => __( 'Shadow color', 'asvg' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#000000A8',
				'selectors' => [
					'{{WRAPPER}} svg:hover' => 'filter: drop-shadow({{shadow_x_hover.SIZE}}{{shadow_x_hover.UNIT}} {{shadow_y_hover.SIZE}}{{shadow_y_hover.UNIT}} {{shadow_blur_hover.SIZE}}{{shadow_blur_hover.UNIT}} {{VALUE}}); ',
                ],
                'condition' => [
					'shadow_add_hover' => 'yes',
				],
			]
		);


		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'lottie_border_hover',
				'selector' => '{{WRAPPER}} .asvg-lotties-animation-wrapper:hover',
				'condition' => [
				'add_border_lottie' => 'yes',
				],
			]
		);

		$this->add_responsive_control(
			'border_radius_lottie_hover',
					[
				'render_type' => 'ui',
				'type' 			=> Controls_Manager::DIMENSIONS,
				'label' 		=> __( 'Border Radius', 'asvg' ),
				'size_units' 	=> [ 'px' ],
				'condition' => [
				'add_border_lottie' => 'yes',
				],
				'selectors' => [
					'{{WRAPPER}} .asvg-lotties-animation-wrapper:hover'  => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				]
				);

		$this->add_control(
			'hover_animation_lottie',
			[
				'label' => __( 'Hover animation', 'asvg' ),
				'type' => \Elementor\Controls_Manager::HOVER_ANIMATION,
				'separator' => 'before',
				'prefix_class' => 'elementor-animation-',
			]
		);


		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_control(
			'customize_url',
			[
				'label' => __( '<b>Customize Lottie?</b>', 'asvg' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'asvg' ),
				'label_off' => __( 'No', 'asvg' ),
				'return_value' => 'yes',
				'separator' => 'before',
				'default' => 'no',
				'condition' => [
				'select_svg_option' => [ 'lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_bus', 'lottie_icons_bui', 'lottie_icons_cta', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				]
			]
          );

		$this->add_control(
			'customize',
			[
				'label' => __( '<span style="font-size: 11px; line-height: 1.4">Click on <b>OPEN EDITOR</b> button to customize animation.<br>Watch instructional <a href="https://www.youtube.com/watch?v=gmBVMEp1RMk&t=1936s" target="_blank">video</a> or check out recently added Lotties on <a href="https://lottiefolder.com" target="_blank">LottieFolder.com</a> </span>', 'asvg' ),
				'type' => Controls_Manager::RAW_HTML,
				'condition' => [
				'customize_url' => 'yes',
				'select_svg_option' => [ 'lottie_icons_bas', 'lottie_icons_arr', 'lottie_icons_bus', 'lottie_icons_bui', 'lottie_icons_cta', 'lottie_icons_cta2', 'lottie_icons_fin2', 'lottie_icons_foo', 'lottie_icons_hol', 'lottie_icons_med', 'lottie_icons_mus', 'lottie_icons_obj', 'lottie_icons_off', 'lottie_icons_ret2', 'lottie_icons_smi', 'lottie_icons_sym', 'lottie_icons_tec', 'lottie_icons_txt2', 'lottie_icons_tra', 'lottie_icons_wea', 'lottie_icons_bas2']
				]
			]
		);
		$this->end_controls_section();
	}


	protected function render() {

		$settings = $this->get_settings_for_display();


		$id=uniqid("asvg-lottie");
		$color_main = $settings['color_main'];
		$color_accent = $settings['color_accent'];
		$color_fill = $settings['color_fill'];
		$color_bkg = $settings['color_bkg'];
		$stroke = $settings['stroke'];
		$color_main_hov = $settings['color_main_hov'];
		$color_accent_hov = $settings['color_accent_hov'];
		$color_fill_hov = $settings['color_fill_hov'];
		$color_bkg_hov = $settings['color_bkg_hov'];
		$stroke_hov = $settings['stroke_hov'];
		$hover_transition_lottie = $settings['hover_transition_lottie']['size'];
		$target = '';
        $nofollow = '';

		if ( is_array( $settings['link'] ) ) {
			$target = $settings['link']['is_external'] ? ' target="_blank"' : '';
            $nofollow = $settings['link']['nofollow'] ? ' rel="nofollow"' : '';
		}

		$start_time=$end_time='';
		if(!empty($settings['custom_time']) && $settings['custom_time']=='yes'){
			$start_time = ($settings['start_time']!='') ? $settings['start_time'] : 1;
			$end_time = ($settings['end_time']!='') ? $settings['end_time'] : 100;
		}

		$scrollbased = (!empty($settings['scrollbased'])) ? $settings['scrollbased'] : 'custom';
		$section_duration=500;
		if(!empty($settings['section_duration']['size'])){
			$section_duration = $settings['section_duration']['size'];
		}
		$section_offset=0;
		if(!empty($settings['section_offset']['size'])){
			$section_offset = $settings['section_offset']['size'];
		}

		$loop =(!empty($settings['loop']) && $settings['loop']=='true') ? true : false;
		if((!empty($settings['loop']) && $settings['loop']=='true') && !empty($settings['loop_counter'])){
			$loop = $settings['loop_counter'] - 1;
		}

		$max_width =(!empty($settings['max_width']["size"])) ? $settings['max_width']["size"].$settings['max_width']["unit"] : '100%';
		$minimum_height =(!empty($settings['minimum_height']["size"])) ? $settings['minimum_height']["size"].$settings['minimum_height']["unit"] : '';
		$speed =(!empty($settings['speed']['size'])) ? $settings['speed']['size'] : '1';


		$action ='';
		if(!empty($settings['action'])){
			$action =$settings['action'];
		}
		if ( $settings["anim_renderer"] ) {
			$anim_renderer = esc_attr($settings["anim_renderer"]);
		}

		$content_align=$settings["content_align"];
		$style_atts = $classes = '';
		if ( $content_align ) {
			$classes .= ' align-' . $content_align;
		}

		$animation_effect=$settings["animation_effect"];
		$style_atts = $animation = '';
		if ( $animation_effect ) {
			$animation .= ' ' . $animation_effect ;
		}

		if ( !empty( $anim_renderer ) ) {
			$classes .= ' renderer-' . $anim_renderer;
		}

		if ( !empty( $anim_renderer ) && $anim_renderer == 'html' ) {
			$style_atts .= 'position: relative;';
		}
		if ( !empty( $content_align ) && $content_align == 'right'  ) {
			$style_atts .= 'margin-left: auto;';
		} elseif ( !empty( $content_align ) && $content_align == 'center' ) {
			$style_atts .= 'margin-right: auto;';
			$style_atts .= 'margin-left: auto;';
		}

		$asvg_opt = '';

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_bas'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/bas/del_<?php echo $settings['lottie_icons_bas'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_bas'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/bas/one_<?php echo $settings['lottie_icons_bas'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_bas'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/bas/sync_<?php echo $settings['lottie_icons_bas'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_bas2'){ ?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1628068306/lottiefolder/bas2/<?php echo $settings['lottie_icons_bas2'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				
		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_arr'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/arr/del_<?php echo $settings['lottie_icons_arr'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_arr'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/arr/one_<?php echo $settings['lottie_icons_arr'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_arr'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/arr/sync_<?php echo $settings['lottie_icons_arr'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_cta2'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/cta2/del_<?php echo $settings['lottie_icons_cta2'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_cta2'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/cta2/one_<?php echo $settings['lottie_icons_cta2'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_cta2'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/cta2/sync_<?php echo $settings['lottie_icons_cta2'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_fin2'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/fin2/del_<?php echo $settings['lottie_icons_fin2'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_fin2'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/fin2/one_<?php echo $settings['lottie_icons_fin2'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_fin2'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/fin2/sync_<?php echo $settings['lottie_icons_fin2'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_foo'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/foo/del_<?php echo $settings['lottie_icons_foo'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_foo'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/foo/one_<?php echo $settings['lottie_icons_foo'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_foo'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/foo/sync_<?php echo $settings['lottie_icons_foo'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_hol'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/hol/del_<?php echo $settings['lottie_icons_hol'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_hol'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/hol/one_<?php echo $settings['lottie_icons_hol'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_hol'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/hol/sync_<?php echo $settings['lottie_icons_hol'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_med'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/med/del_<?php echo $settings['lottie_icons_med'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_med'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/med/one_<?php echo $settings['lottie_icons_med'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_med'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/med/sync_<?php echo $settings['lottie_icons_med'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_mus'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/mus/del_<?php echo $settings['lottie_icons_mus'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_mus'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/mus/one_<?php echo $settings['lottie_icons_mus'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_mus'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/mus/sync_<?php echo $settings['lottie_icons_mus'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_obj'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/obj/del_<?php echo $settings['lottie_icons_obj'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_obj'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/obj/one_<?php echo $settings['lottie_icons_obj'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_obj'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/obj/sync_<?php echo $settings['lottie_icons_obj'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_off'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/off/del_<?php echo $settings['lottie_icons_off'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_off'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/off/one_<?php echo $settings['lottie_icons_off'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_off'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/off/sync_<?php echo $settings['lottie_icons_off'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_ret2'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/ret2/del_<?php echo $settings['lottie_icons_ret2'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_ret2'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/ret2/one_<?php echo $settings['lottie_icons_ret2'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_ret2'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/ret2/sync_<?php echo $settings['lottie_icons_ret2'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_smi'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/smi/del_<?php echo $settings['lottie_icons_smi'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_smi'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/smi/one_<?php echo $settings['lottie_icons_smi'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_smi'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/smi/sync_<?php echo $settings['lottie_icons_smi'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_sym'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/sym/del_<?php echo $settings['lottie_icons_sym'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_sym'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/sym/one_<?php echo $settings['lottie_icons_sym'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_sym'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/sym/sync_<?php echo $settings['lottie_icons_sym'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_tec'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/tec/del_<?php echo $settings['lottie_icons_tec'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_tec'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/tec/one_<?php echo $settings['lottie_icons_tec'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_tec'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/tec/sync_<?php echo $settings['lottie_icons_tec'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_txt2'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/txt2/del_<?php echo $settings['lottie_icons_txt2'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_txt2'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/txt2/one_<?php echo $settings['lottie_icons_txt2'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_txt2'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/txt2/sync_<?php echo $settings['lottie_icons_txt2'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_tra'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/tra/del_<?php echo $settings['lottie_icons_tra'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_tra'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/tra/one_<?php echo $settings['lottie_icons_tra'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_tra'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/tra/sync_<?php echo $settings['lottie_icons_tra'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_wea'){
		if($settings['mode'] == 'del'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/wea/del_<?php echo $settings['lottie_icons_wea'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_wea'){
		if($settings['mode'] == 'one'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/wea/one_<?php echo $settings['lottie_icons_wea'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['customize_url'] == 'yes'){
		if($settings['select_svg_option'] == 'lottie_icons_wea'){
		if($settings['mode'] == 'sync'){	?>
		<button style="padding: 3px 6px;font-size:12px" onClick="popup01('https://edit.lottiefiles.com/?src=https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/wea/sync_<?php echo $settings['lottie_icons_wea'];?>', 'Name',1400,800)" class="button-primary">OPEN EDITOR</button>
		<script language="javascript" type="text/javascript">
        function popup01(pageURL, title, w, h) {
            var left = (screen.width - w) / 4;
            var top = (screen.height - h) / 3;
            var targetWin = window.open(pageURL, title, 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
			}
			</script><?php
				}
				}
				}

		if($settings['select_svg_option'] == 'lottie_icons_bas' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/bas/del_'.$settings['lottie_icons_bas'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

			

		if($settings['select_svg_option'] == 'lottie_icons_bas'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/bas/one_'.$settings['lottie_icons_bas'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_bas'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/bas/sync_'.$settings['lottie_icons_bas'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_bas2'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1627308357/lottiefolder/bas2/'.$settings['lottie_icons_bas2'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}


		if($settings['select_svg_option'] == 'lottie_icons_arr' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/arr/del_'.$settings['lottie_icons_arr'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_arr'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/arr/one_'.$settings['lottie_icons_arr'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_arr'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/arr/sync_'.$settings['lottie_icons_arr'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_bus' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/bus/del_'.$settings['lottie_icons_bus'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_bus'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/bus/one_'.$settings['lottie_icons_bus'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_bus'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/bus/sync_'.$settings['lottie_icons_bus'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_bui' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/bui/del_'.$settings['lottie_icons_bui'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_bui'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/bui/one_'.$settings['lottie_icons_bui'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_bui'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/bui/sync_'.$settings['lottie_icons_bui'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_cta2' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/cta2/del_'.$settings['lottie_icons_cta2'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_cta2'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/cta2/one_'.$settings['lottie_icons_cta2'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_cta2'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/cta2/sync_'.$settings['lottie_icons_cta2'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_fin2' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/fin2/del_'.$settings['lottie_icons_fin2'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_fin2'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/fin2/one_'.$settings['lottie_icons_fin2'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_fin2'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/fin2/sync_'.$settings['lottie_icons_fin2'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}


		if($settings['select_svg_option'] == 'lottie_icons_foo' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/foo/del_'.$settings['lottie_icons_foo'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_foo'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/foo/one_'.$settings['lottie_icons_foo'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_foo'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/foo/sync_'.$settings['lottie_icons_foo'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}


		if($settings['select_svg_option'] == 'lottie_icons_hol' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/hol/del_'.$settings['lottie_icons_hol'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_hol'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/hol/one_'.$settings['lottie_icons_hol'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_hol'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/hol/sync_'.$settings['lottie_icons_hol'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}


		if($settings['select_svg_option'] == 'lottie_icons_med' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/med/del_'.$settings['lottie_icons_med'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_med'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/med/one_'.$settings['lottie_icons_med'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_med'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/med/sync_'.$settings['lottie_icons_med'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}


		if($settings['select_svg_option'] == 'lottie_icons_mus' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/mus/del_'.$settings['lottie_icons_mus'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_mus'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/mus/one_'.$settings['lottie_icons_mus'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_mus'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/mus/sync_'.$settings['lottie_icons_mus'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}


		if($settings['select_svg_option'] == 'lottie_icons_obj' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/obj/del_'.$settings['lottie_icons_obj'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_obj'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/obj/one_'.$settings['lottie_icons_obj'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_obj'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/obj/sync_'.$settings['lottie_icons_obj'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_off' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/off/del_'.$settings['lottie_icons_off'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_off'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/off/one_'.$settings['lottie_icons_off'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_off'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/off/sync_'.$settings['lottie_icons_off'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}


		if($settings['select_svg_option'] == 'lottie_icons_peo' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/peo/del_'.$settings['lottie_icons_peo'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_peo'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/peo/one_'.$settings['lottie_icons_peo'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_peo'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/peo/sync_'.$settings['lottie_icons_peo'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}


		if($settings['select_svg_option'] == 'lottie_icons_ret2' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/ret2/del_'.$settings['lottie_icons_ret2'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_ret2'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/ret2/one_'.$settings['lottie_icons_ret2'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_ret2'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/ret2/sync_'.$settings['lottie_icons_ret2'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_sci' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/sci/del_'.$settings['lottie_icons_sci'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_sci'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/sci/one_'.$settings['lottie_icons_sci'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_sci'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/sci/sync_'.$settings['lottie_icons_sci'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}


		if($settings['select_svg_option'] == 'lottie_icons_smi' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/smi/del_'.$settings['lottie_icons_smi'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_smi'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/smi/one_'.$settings['lottie_icons_smi'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_smi'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/smi/sync_'.$settings['lottie_icons_smi'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}


		if($settings['select_svg_option'] == 'lottie_icons_sym' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/sym/del_'.$settings['lottie_icons_sym'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_sym'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/sym/one_'.$settings['lottie_icons_sym'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_sym'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/sym/sync_'.$settings['lottie_icons_sym'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_tec' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/tec/del_'.$settings['lottie_icons_tec'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_tec'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/tec/one_'.$settings['lottie_icons_tec'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_tec'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/tec/sync_'.$settings['lottie_icons_tec'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_txt2' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/txt2/del_'.$settings['lottie_icons_txt2'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_txt2'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/txt2/one_'.$settings['lottie_icons_txt2'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_txt2'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/txt2/sync_'.$settings['lottie_icons_txt2'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_tra' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/tra/del_'.$settings['lottie_icons_tra'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_tra'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/tra/one_'.$settings['lottie_icons_tra'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_tra'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/tra/sync_'.$settings['lottie_icons_tra'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_wea' &&  $settings['mode'] == 'del') {
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/wea/del_'.$settings['lottie_icons_wea'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}

		if($settings['select_svg_option'] == 'lottie_icons_wea'){
			if($settings['mode'] == 'one'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/wea/one_'.$settings['lottie_icons_wea'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		if($settings['select_svg_option'] == 'lottie_icons_wea'){
			if($settings['mode'] == 'sync'){
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="https://res.cloudinary.com/lottiefolder/raw/upload/v1621769936/lottiefolder/wea/sync_'.$settings['lottie_icons_wea'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
			}

		$op ='';

		if($settings["link_delay_switch"] == 'yes'){ ?>
			<script>(function($){"use strict";$( document ).ready(function(){$("#<?php echo $id ?>").css('cursor', 'pointer').click(function(e){e.preventDefault();setTimeout(function(){window.open('<?php echo esc_attr($settings['link']['url'])?>'<?php if ($settings['link_delay_blank'] == 'yes'){ echo ', \'_self\'';}?>)}, <?php echo esc_attr($settings['link_delay']['size'])?>);});});})(jQuery);</script><?php
			}
			else {
			if($settings['add_link'] == 'yes'){	?>
			<a href="<?php echo esc_url($settings['link']['url']); ?>" <?php echo  esc_attr($target) . esc_attr($nofollow); ?>>
			<?php
			}
			}
		$op .='<div id="'.esc_attr($id).'" class="asvg-lotties-animation-wrapper asvg-'.esc_attr($id).' '.$classes.' '.$animation.'"  style="'.$style_atts.'" '.$asvg_opt.'></div>';

		?>
		<style>
		#<?php echo $id ?> g.main path {
			stroke: <?php echo $color_main ?>;
			stroke-width: <?php echo $stroke ?>;
			transition-property: stroke-width, stroke;
			transition-duration: <?php echo esc_attr($settings['hover_transition_lottie']['size']) ?>s;
		}
		#<?php echo $id ?> path {
			stroke-width: <?php echo $stroke ?>;
			transition-property: stroke-width, stroke;
			transition-duration: <?php echo esc_attr($settings['hover_transition_lottie']['size']) ?>s;
		}
		#<?php echo $id ?> g.accent path {
			stroke: <?php echo $color_accent ?>;
			stroke-width: <?php echo $stroke ?>;
			transition-property: stroke-width, stroke;
			transition-duration: <?php echo esc_attr($settings['hover_transition_lottie']['size']) ?>s;
		}
		#<?php echo $id ?> g.fill path {
			fill: <?php echo $color_fill ?>;
			transition-property: fill;
			transition-duration: <?php echo esc_attr($settings['hover_transition_lottie']['size']) ?>s;
		}
		#<?php echo $id ?>:hover path {
			stroke-width: <?php echo $stroke_hov ?>;
		}
		#<?php echo $id ?>:hover g.main path {
			stroke: <?php echo $color_main_hov ?>;
			stroke-width: <?php echo $stroke_hov ?>;
		}
		#<?php echo $id ?>:hover g.accent path {
			stroke: <?php echo $color_accent_hov ?>;
			stroke-width: <?php echo $stroke_hov ?>;
		}
		#<?php echo $id ?>:hover g.fill path {
			fill: <?php echo $color_fill_hov ?>;
		}
		svg {
			transition-duration: <?php echo esc_attr($settings['hover_transition_lottie']['size']) ?>s;
		}
		#<?php echo $id ?> .asvg-lotties-animation-wrapper path { transition: <?php echo esc_attr($settings['hover_transition_lottie']['size']) ?>s ease; }
		.asvg-lotties-animation-wrapper, .asvg-<?php echo $id ?> {
			transition-duration: <?php echo esc_attr($settings['hover_transition_lottie']['size']) ?>s;
		}
		</style><?php
		if($settings['add_link'] == 'yes'){
		$op .='</a>';
		}
		echo $op;
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new ASVGLottie_FREE() );