<?php
namespace Elementor;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;


class ASVG_upload_FREE extends Widget_Base {

	public function get_name() {
		return 'asvg_upload_free';
	}

	public function get_title() {
		return esc_html__('Upload Lottie', 'asvg');
	}

	public function get_icon() {
		 return 'asvg icon-upload';
	}
	public function get_categories() {
        return array('animated-svg');
    }

	public function get_script_depends() {
		return ['lottie_asvg', 'asvg_lottie_icons'];
	}

    public function get_keywords() {
        return [ 'upload', 'animation', 'asvg', 'lottie', ];
    }

	protected function _register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Lottie Animation', 'asvg' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'select_svg_option',
			[
				'label' => __( 'Select source', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'label_block' => true,
				'default' => 'json_url',
				'options' => [
					'json_url'  => __( 'Enter Lottie URL', 'asvg' ),
					'data_file'  => __( 'Upload Lottie', 'asvg' ),
				],
			]
		);

		$this->add_control(
			'json_url',
			[
				'label' => esc_html__( 'Lottie URL', 'asvg' ),
				'type' => Controls_Manager::URL,
				'placeholder' => esc_html__( 'Enter Lottie URL here', 'asvg' ),
				'default' => [
					'url' => 'https://assets10.lottiefiles.com/packages/lf20_frzhikg2.json',
				],
				'condition' => [
					'select_svg_option' => 'json_url',
				],
			]
		);

		$this->add_control(
			'lottie_info',
			[
				'label' => __( '<span style="font-size:11px">Browse from 1000s of free animations on: <a href="https://lottiefiles.com/featured" target="_blank">lottiefiles.com</a></span>', 'asvg' ),
				'type' => Controls_Manager::RAW_HTML,
				'condition' => [
					'select_svg_option' => 'json_url',
				],
			]
		);

		$this->add_control(
			'data_file',
      			array(
        		'label'       => __( 'Upload your json file', 'asvg' ),
				'condition'   => array(
					'select_svg_option' => 'data_file',
				),
        		'type'        => \Elementor\Controls_Manager::MEDIA,
        		'media_type'  => 'application/json',
		  )
		);

		$this->add_control(
			'action',
			[
				'label' => __( 'Play setting', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'hover_auto',
				'options' => [
					'autoplay'			=> __( 'Autoplay', 'asvg' ),
					'hover_auto'		=> __( 'Autoplay + on hover', 'asvg' ),
					'click_auto'		=> __( 'Autoplay + on click', 'asvg' ),
					'viewport'			=> __( 'Play in viewport', 'asvg' ),
					'hover'				=> __( 'Play in viewport + on hover', 'asvg' ),
					'click'   			=> __( 'Play in viewport + on click', 'asvg' ),
					'parallax_effect'	=> __( 'Play on scroll', 'asvg' ),
				],
			]
		);

		$this->add_control(
			'loop',
			[
				'label' => esc_html__( 'Continuous loop', 'asvg' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'OFF', 'asvg' ),
				'label_off' => esc_html__( 'ON', 'asvg' ),
				'return_value' => 'true',
				'default' => 'true',
				'condition' => [
				'action' => ['autoplay', 'hover', 'hover_auto', 'click', 'click_auto', 'viewport'],
			]
			]
		);

		$this->add_control(
			'loop_counter',
			[
				'label' => esc_html__( 'Number of times to play (1-99)', 'asvg' ),
				'type' => Controls_Manager::NUMBER,
				'default' => '1',
				'min' => 1,
				'max' => 99,
				'step' => 1,
				'condition' => [
				'action' => ['autoplay', 'hover', 'hover_auto', 'click', 'click_auto', 'viewport'],
				'loop' => 'true',
				],
			]
		);

		$this->add_control(
			'scrollbased',
			[
				'label' => __( 'Scroll settings', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'custom',
				'options' => [
					'custom' => __( 'Viewport', 'asvg' ),
					'document'  => __( 'Entire page', 'asvg' ),
				],
				'description' => __( '<span style="font-size: 11px; font-style: normal; line-height: 1.4">In "Viewport" mode, you need to set duration and offset for animation. If you select "Entire page", animation will be based on whole page\'s height.</span>', 'asvg' ),
				'condition' => [
					'action' => 'parallax_effect',
				],
			]
		);

		$this->add_control(
			'section_duration',
			[
				'label' => __( 'Duration', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 50,
						'max' => 2000,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 400,
				],
				'condition' => [
					'action' => 'parallax_effect',
					'scrollbased' => 'custom',
				],
			]
		);

		$this->add_control(
			'section_offset',
			[
				'label' => __( 'Offset', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => -1000,
						'max' => 1000,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 400,
				],
				'condition' => [
					'action' => 'parallax_effect',
					'scrollbased' => 'custom',
				],
			]
		);

		$this->add_control(
			'speed',
			[
				'label' => esc_html__( 'Play speed (0.1- 5)', 'asvg' ),
				'type'  => Controls_Manager::SLIDER,
				'separator' => 'before',
				'range' => [
					'px' => [
						'min' => 0.1,
						'max' => 5,
                        'step' => 0.1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1,
				],
				'condition' => [
					'action' => ['autoplay', 'hover_auto','click_auto', 'viewport', 'hover', 'click'],
				],
			]
		);

		$this->add_control(
			'custom_time',
			[
				'label' => esc_html__( 'Custom animation timing', 'asvg' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'ON', 'asvg' ),
				'label_off' => esc_html__( 'OFF', 'asvg' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
					'action' => 'parallax_effect',
				],
			]
		);

		$this->add_control(
			'start_time',
			[
				'label' => esc_html__( 'Start time (frame no.)', 'asvg' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 5000,
				'step' => 10,
				'default' => '1',
				'condition' => [
					'action' =>  'parallax_effect',
					'custom_time' => 'yes',
				],
			]
		);

		$this->add_control(
			'end_time',
			[
				'label' => esc_html__( 'End time (frame no.)', 'asvg' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 5000,
				'step' => 10,
				'default' => '100',
				'condition' => [
					'action' => 'parallax_effect',
					'custom_time' => 'yes',
				],
			]
		);

		$this->add_control(
			'add_link',
			[
				'label' => esc_html__( 'Add link', 'asvg' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'yes', 'asvg' ),
				'label_off' => esc_html__( 'no', 'asvg' ),
				'default' => 'no',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'link',
			[
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'asvg' ),
				'show_external' => true,
				'default' => [
					'url' => '',
				],
				'condition' => [
					'add_link' => 'yes',
				],
			]
		);

		$this->add_control(
			'link_delay_switch',
			[
				'label' => __( 'Add delay when clicked?', 'asvg' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'asvg' ),
				'label_off' => __( 'No', 'asvg' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'action' => ['click', 'click_auto', 'hover', 'hover_auto'],
					'add_link' => 'yes',
				],
			]
          );

		$this->add_control(
			'link_delay',
			[
				'label' => esc_html__( 'Click delay (ms)', 'asvg' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 100,
						'max' => 10000,
                        'step' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1000,
				],
				'condition' => [
					'action' => ['click', 'click_auto', 'hover', 'hover_auto'],
					'add_link' => 'yes',
					'link_delay_switch' => 'yes',
				],
			]
		);

		$this->add_control(
			'link_delay',
			[
				'label' => esc_html__( 'Click delay (in ms)', 'asvg' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 100,
						'max' => 10000,
                        'step' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 1000,
				],
				'condition' => [
					'link' => 'yes',
				],
				'frontend_available' => true,
			]
		);

		$this->add_control(
			'link_delay_blank',
			[
				'label' => __( 'Open link in same browser tab?', 'asvg' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'asvg' ),
				'label_off' => __( 'No', 'asvg' ),
				'return_value' => 'yes',
				'default' => 'yes',
				'condition' => [
					'action' => ['click', 'click_auto', 'hover', 'hover_auto'],
					'add_link' => 'yes',
					'link_delay_switch' => 'yes',
				],
			]

          );

		$this->end_controls_section();

/*STYLE*/

		$this->start_controls_section(
			'section_lotties_option',
			[
				'label' => esc_html__( 'Lottie Style', 'asvg' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'content_align',
			[
				'label' => esc_html__( 'Alignment', 'asvg' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'asvg' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'asvg' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'asvg' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'center',
				'prefix_ class' => 'text-%s',
			]
		);

		$this->add_responsive_control(
			'max_width',
			[
				'label' => esc_html__( 'Maximum width', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => '%',
					'size' => 50,
				],
				'render_type' => 'ui',
				'selectors' => [
					'{{WRAPPER}} .asvg-lotties-animation-wrapper' => 'max-width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'lottie_margin',
			[
				'label' => __( 'Margin (in pixels)', 'asvg' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px'],
				'selectors' => [
					'{{WRAPPER}} .asvg-lotties-animation-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'after',
			]
		);

		$this->add_control(
			'space',
			[
				'label' => __( '<br>Styling options<br>', 'asvg' ),
				'type' => Controls_Manager::RAW_HTML,

			]
		);

		$this->start_controls_tabs( 'image_effects' );

/* Normal */

		$this->start_controls_tab( 'normal_lottie',
			array(
				'label' => __( 'Normal', 'asvg' ),
			)
		);

		$this->add_control(
			'stroke_change',
			[
				'label' => __( 'Change stroke width?', 'asvg' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'asvg' ),
				'label_off' => __( 'No', 'asvg' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
          );

		$this->add_control(
            'stroke',
			[
				'label' => esc_html__( 'Stroke width', 'asvg' ),
				'type' => Controls_Manager::NUMBER,
				'label_block' => false,
				'min' => 1,
				'max' => 30,
				'step' => 1,
				'default' => 18,
                'dynamic' => [
                    'active' => false,
                  ],
				'condition' => [
					'stroke_change' => 'yes',
				],
			]
		);

		$this->add_control(
			'rotate_lottie',
			[
				'label' => __( 'Rotation', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 0,
					'unit' => 'deg',
				],
				'selectors' => [
					'{{WRAPPER}} .asvg-lotties-animation-wrapper' => 'transform: rotate({{SIZE}}{{UNIT}});',
			],
			]
		);

		$this->add_control(
			'opacity_lottie',
			array(
				'label' => __( 'Opacity', 'asvg' ),
				'type'  => \Elementor\Controls_Manager::SLIDER,
				'range' => array(
					'px'  => array(
						'max'   => 1,
						'min'   => 0.10,
						'step'  => 0.01,
					),
				),
				'default' => [
					'size' => 1,
				],
				'selectors' => array(
					'{{WRAPPER}} .asvg-lotties-animation-wrapper' => 'opacity: {{SIZE}};',
				),
			)
		);

		$this->add_group_control(
			\Elementor\Group_Control_Css_Filter::get_type(),
			array(
				'name' => 'css_filters_lottie',
				'selector' => '{{WRAPPER}} .asvg-lotties-animation-wrapper',
			)
		);

		$this->add_control(
      		'shadow_add',
			[
                'label' => __( 'Shadow', 'asvg' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'asvg' ),
				'label_off' => __( 'No', 'asvg' ),
				'return_value' => 'yes',
				'default' => 'no',
				'frontend_available' => true,
			]
        );

		$this->add_control(
      		'shadow_x',
			 [
				'label' => __( 'Offset X', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => -50,
						'max' => 50,
						'step' => 1,
					],
					'em' => [
                        'min' => -5,
						'max' => 5,
						'step' => 0.1,
					],
                ],
                'default' => [
					'unit' => 'px',
					'size' => 2,
				],
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} svg' => 'filter: drop-shadow({{SIZE}}{{UNIT}} {{shadow_y.SIZE}}{{shadow_y.UNIT}} {{shadow_blur.SIZE}}{{shadow_blur.UNIT}} {{shadow_color.VALUE}});',
                ],
                'condition' => [
					'shadow_add' => 'yes',
				],
			]
        );

		$this->add_control(
			'shadow_y',
            [
				'label' => __( 'Offset Y', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => -50,
						'max' => 50,
						'step' => 1,
					],
					'em' => [
                        'min' => -5,
						'max' => 5,
						'step' => 0.1,
					],
                ],
                'default' => [
					'unit' => 'px',
					'size' => 0,
				],
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} svg' => 'filter: drop-shadow({{shadow_x.SIZE}}{{shadow_x.UNIT}} {{SIZE}}{{UNIT}} {{shadow_blur.SIZE}}{{shadow_blur.UNIT}} {{shadow_color.VALUE}});',
                ],
                'condition' => [
					'shadow_add' => 'yes',
				],
			]
        );

		$this->add_control(
            'shadow_blur',
            [
				'label' => __( 'Blur', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
						'step' => 1,
					],
					'em' => [
						'max' => 10,
						'step' => 0.1,
					],
                ],
                'default' => [
					'unit' => 'px',
					'size' => 0,
				],
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} svg' => 'filter: drop-shadow({{shadow_x.SIZE}}{{shadow_x.UNIT}} {{shadow_y.SIZE}}{{shadow_y.UNIT}} {{SIZE}}{{UNIT}} {{shadow_color.VALUE}});',
                ],
                'condition' => [
					'shadow_add' => 'yes',
				],
			]
        );

		$this->add_control(
 			'shadow_color',
			[
				'label' => __( 'Shadow color', 'asvg' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#0000005E',
				'selectors' => [
					'{{WRAPPER}} svg' => 'filter: drop-shadow({{shadow_x.SIZE}}{{shadow_x.UNIT}} {{shadow_y.SIZE}}{{shadow_y.UNIT}} {{shadow_blur.SIZE}}{{shadow_blur.UNIT}} {{VALUE}});',
                ],
                'condition' => [
					'shadow_add' => 'yes',
				],
			]
		);

		$this->add_control(
      		'add_border_lottie',
      			[
        		'label'     => __( 'Border', 'asvg' ),
        		'type'      => Controls_Manager::SWITCHER,
				'label_on' => __( 'yes', 'asvg' ),
				'label_off' => __( 'no', 'asvg' ),
				'return_value' => 'yes',
				'default' => 'no',
      			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'lottie_border',
				'selector' => '{{WRAPPER}} .asvg-lotties-animation-wrapper',
				'condition' => [
				'add_border_lottie' => 'yes',
				],
			]
		);

		$this->add_responsive_control(
			'border_radius_lottie',
					[
				'render_type' => 'ui',
				'type' 			=> Controls_Manager::DIMENSIONS,
				'label' 		=> __( 'Border Radius', 'asvg' ),
				'size_units' 	=> [ 'px' ],
				'condition' => [
				'add_border_lottie' => 'yes',
				],
				'selectors' => [
					'{{WRAPPER}} .asvg-lotties-animation-wrapper'  => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				]
				);

		$this->add_control(
			'continuous_animation',
			[
				'label' => __( 'Continuous animation',  'asvg' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'asvg' ),
				'label_off'    => esc_html__( 'No', 'asvg' ),
				'render_type'  => 'template',
				'separator' => 'before',
			]
		);

		$this->add_control(
			'animation_effect',
			[
				'label' => __( 'Animation effect', 'asvg' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'tossing',
				'options' => [
					'pulse-asvg'  => __( 'Pulse', 'asvg' ),
					'heartbeat'  => __( 'Heartbeat', 'asvg' ),
					'floating'  => __( 'Floating', 'asvg' ),
					'flip-horizontal-top'  => __( 'Flip', 'asvg' ),
					'tossing'  => __( 'Tossing', 'asvg' ),
					'rotate-continue'  => __( 'Rotating', 'asvg' ),
					'rotate-center'  => __( 'Rotate/Pause CCW', 'asvg' ),
				],
				'condition' => [
				'continuous_animation' => 'yes',
				],
			]
		);

		$this->end_controls_tab();

/* Hover */

		$this->start_controls_tab( 'hover_lottie',
			array(
				'label' => __( 'Hover', 'asvg' ),
			)
		);

		$this->add_control(
            'stroke_hov',
			[
				'label' => esc_html__( 'Stroke width', 'asvg' ),
				'type' => Controls_Manager::NUMBER,
				'label_block' => false,
				'min' => 1,
				'max' => 30,
				'step' => 1,
				'default' => 18,
                'dynamic' => [
                    'active' => false,
                  ],
				'condition' => [
					'stroke_change' => 'yes',
				],
			]
		);

		$this->add_control(
			'rotate_lottie_hov',
			[
				'label' => __( 'Rotation', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [
					'size' => 0,
					'unit' => 'deg',
				],
				'selectors' => [
					'{{WRAPPER}} .asvg-lotties-animation-wrapper:hover' => 'transform: rotate({{SIZE}}{{UNIT}});',
				],
			]
		);

		$this->add_control(
			'opacity_lottie_hover',
			array(
				'label' => __( 'Opacity', 'asvg' ),
				'type'  => \Elementor\Controls_Manager::SLIDER,
				'range' => array(
					'px'  => array(
						'max'   => 1,
						'min'   => 0.10,
						'step'  => 0.01,
					),
				),
				'default' => [
					'size' => 1,
				],
				'selectors' => array(
					'{{WRAPPER}} .asvg-lotties-animation-wrapper:hover' => 'opacity: {{SIZE}};',
				),
			)
		);

		$this->add_control(
			'hover_transition_lottie',
			array(
				'label' => __( 'Transition duration', 'asvg' ),
				'type'  => \Elementor\Controls_Manager::SLIDER,
				'range' => array(
					'px'  => array(
						'max'   => 10,
						'step'  => 0.1,
					),
				),
				'default' => [
					'size' => 3,
				],
			)
		);

		$this->add_group_control(
			\Elementor\Group_Control_Css_Filter::get_type(),
			array(
				'name' => 'css_filters_lottie_hover',
				'selector' => '{{WRAPPER}} .asvg-lotties-animation-wrapper:hover',
			)
		);

		$this->add_control(
      		'shadow_add_hover',
			[
                'label' => __( 'Shadow', 'asvg' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'asvg' ),
				'label_off' => __( 'No', 'asvg' ),
				'return_value' => 'yes',
				'default' => 'no',
				'frontend_available' => true,
			]
        );

		$this->add_control(
      		'shadow_x_hover',
			 [
				'label' => __( 'Offset X', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => -50,
						'max' => 50,
						'step' => 1,
					],
					'em' => [
                        'min' => -5,
						'max' => 5,
						'step' => 0.1,
					],
                ],
                'default' => [
					'unit' => 'px',
					'size' => 2,
				],
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} svg:hover' => 'filter: drop-shadow({{SIZE}}{{UNIT}} {{shadow_y_hover.SIZE}}{{shadow_y_hover.UNIT}} {{shadow_blur_hover.SIZE}}{{shadow_blur_hover.UNIT}} {{shadow_color_hover.VALUE}});',
                ],
                'condition' => [
					'shadow_add_hover' => 'yes',
				],
			]
        );

		$this->add_control(
			'shadow_y_hover',
            [
				'label' => __( 'Offset Y', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
                        'min' => -50,
						'max' => 50,
						'step' => 1,
					],
					'em' => [
                        'min' => -5,
						'max' => 5,
						'step' => 0.1,
					],
                ],
                'default' => [
					'unit' => 'px',
					'size' => 2,
				],
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} svg:hover' => 'filter: drop-shadow({{shadow_x_hover.SIZE}}{{shadow_x_hover.UNIT}} {{SIZE}}{{UNIT}} {{shadow_blur_hover.SIZE}}{{shadow_blur_hover.UNIT}} {{shadow_color_hover.VALUE}});',
                ],
                'condition' => [
					'shadow_add_hover' => 'yes',
				],
			]
        );

		$this->add_control(
            'shadow_blur_hover',
            [
				'label' => __( 'Blur', 'asvg' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
						'step' => 1,
					],
					'em' => [
						'max' => 10,
						'step' => 0.1,
					],
                ],
                'default' => [
					'unit' => 'px',
					'size' => 2,
				],
				'size_units' => [ 'px', 'em' ],
				'selectors' => [
					'{{WRAPPER}} svg:hover' => 'filter: drop-shadow({{shadow_x_hover.SIZE}}{{shadow_x_hover.UNIT}} {{shadow_y_hover.SIZE}}{{shadow_y_hover.UNIT}} {{SIZE}}{{UNIT}} {{shadow_color_hover.VALUE}});',
                ],
                'condition' => [
					'shadow_add_hover' => 'yes',
				],
			]
        );

		$this->add_control(
 			'shadow_color_hover',
			[
				'label' => __( 'Shadow color', 'asvg' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#000000A8',
				'selectors' => [
					'{{WRAPPER}} svg:hover' => 'filter: drop-shadow({{shadow_x_hover.SIZE}}{{shadow_x_hover.UNIT}} {{shadow_y_hover.SIZE}}{{shadow_y_hover.UNIT}} {{shadow_blur_hover.SIZE}}{{shadow_blur_hover.UNIT}} {{VALUE}}); ',
                ],
                'condition' => [
					'shadow_add_hover' => 'yes',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'lottie_border_hover',
				'selector' => '{{WRAPPER}} .asvg-lotties-animation-wrapper:hover',
				'condition' => [
				'add_border_lottie' => 'yes',
				],
			]
		);

		$this->add_responsive_control(
			'border_radius_lottie_hover',
					[
				'render_type' => 'ui',
				'type' 			=> Controls_Manager::DIMENSIONS,
				'label' 		=> __( 'Border Radius', 'asvg' ),
				'size_units' 	=> [ 'px' ],
				'condition' => [
				'add_border_lottie' => 'yes',
				],
				'selectors' => [
					'{{WRAPPER}} .asvg-lotties-animation-wrapper:hover'  => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				]
				);

		$this->add_control(
			'hover_animation_lottie',
			[
				'label' => __( 'Hover animation', 'asvg' ),
				'type' => \Elementor\Controls_Manager::HOVER_ANIMATION,
				'separator' => 'before',
				'prefix_class' => 'elementor-animation-',
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}


	protected function render() {

		$settings = $this->get_settings_for_display();

		$id=uniqid("asvg-lottie");
		$stroke = $settings['stroke'];
		$stroke_hov = $settings['stroke_hov'];
		$hover_transition_lottie = $settings['hover_transition_lottie']['size'];
		$target = '';
        $nofollow = '';

		if ( is_array( $settings['link'] ) ) {
			$target = $settings['link']['is_external'] ? ' target="_blank"' : '';
            $nofollow = $settings['link']['nofollow'] ? ' rel="nofollow"' : '';
		}

		$start_time=$end_time='';
		if(!empty($settings['custom_time']) && $settings['custom_time']=='yes'){
			$start_time = ($settings['start_time']!='') ? $settings['start_time'] : 1;
			$end_time = ($settings['end_time']!='') ? $settings['end_time'] : 100;
		}

		$scrollbased = (!empty($settings['scrollbased'])) ? $settings['scrollbased'] : 'custom';
		$section_duration=500;
		if(!empty($settings['section_duration']['size'])){
			$section_duration = $settings['section_duration']['size'];
		}
		$section_offset=0;
		if(!empty($settings['section_offset']['size'])){
			$section_offset = $settings['section_offset']['size'];
		}

		$loop =(!empty($settings['loop']) && $settings['loop']=='true') ? true : false;
		if((!empty($settings['loop']) && $settings['loop']=='true') && !empty($settings['loop_counter'])){
			$loop = $settings['loop_counter'] - 1;
		}

		$max_width =(!empty($settings['max_width']["size"])) ? $settings['max_width']["size"].$settings['max_width']["unit"] : '100%';
		$minimum_height =(!empty($settings['minimum_height']["size"])) ? $settings['minimum_height']["size"].$settings['minimum_height']["unit"] : '';
		$speed =(!empty($settings['speed']['size'])) ? $settings['speed']['size'] : '1';


		$action ='';
		if(!empty($settings['action'])){
			$action =$settings['action'];
		}
		if ( $settings["anim_renderer"] ) {
			$anim_renderer = esc_attr($settings["anim_renderer"]);
		}

		$content_align=$settings["content_align"];
		$style_atts = $classes = '';
		if ( $content_align ) {
			$classes .= ' align-' . $content_align;
		}

		$animation_effect=$settings["animation_effect"];
		$style_atts = $animation = '';
		if ( $animation_effect ) {
			$animation .= ' ' . $animation_effect ;
		}

		if ( !empty( $anim_renderer ) ) {
			$classes .= ' renderer-' . $anim_renderer;
		}

		if ( !empty( $anim_renderer ) && $anim_renderer == 'html' ) {
			$style_atts .= 'position: relative;';
		}
		if ( !empty( $content_align ) && $content_align == 'right'  ) {
			$style_atts .= 'margin-left: auto;';
		} elseif ( !empty( $content_align ) && $content_align == 'center' ) {
			$style_atts .= 'margin-right: auto;';
			$style_atts .= 'margin-left: auto;';
		}

		$asvg_opt = '';

		if ( $settings['json_url']['url'] != '' ) {
			$PATHINFO_EXTENSION = pathinfo($settings['json_url']['url'], PATHINFO_EXTENSION);
			if($PATHINFO_EXTENSION!='json'){
				echo '<h4>'.esc_html__("Please enter Lottie URL.",'asvg').'</h4>';
				return false;
			}else{
				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="'.$settings['json_url']['url'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
			}
		}

		if ( $settings['data_file']!= '' ) {

				$asvg_opt =  'data-id="'.$id.'"';
				$asvg_opt .=  ' data-path="'.$settings['data_file']['url'].'"';
				$asvg_opt .=  ' data-loop="'.$loop.'"';
				$asvg_opt .=  ' data-width="'.$max_width.'"';
				$asvg_opt .=  ' data-height="'.$minimum_height.'"';
				$asvg_opt .=  ' data-playspeed="'.$speed.'"';
				$asvg_opt .=  ' data-play_action="'.$action.'"';
				$asvg_opt .=  ' data-scrollbased="'.$scrollbased.'"';
				$asvg_opt .=  ' data-section_duration="'.$section_duration.'"';
				$asvg_opt .=  ' data-section_offset="'.$section_offset.'"';
				$asvg_opt .=  ' data-start_time="'.$start_time.'"';
				$asvg_opt .=  ' data-end_time="'.$end_time.'"';
		}

		$op ='';

		if($settings["link_delay_switch"] == 'yes'){ ?>
			<script>(function($){"use strict";$( document ).ready(function(){$("#<?php echo $id ?>").css('cursor', 'pointer').click(function(e){e.preventDefault();setTimeout(function(){window.open('<?php echo esc_attr($settings['link']['url'])?>'<?php if ($settings['link_delay_blank'] == 'yes'){ echo ', \'_self\'';}?>)}, <?php echo esc_attr($settings['link_delay']['size'])?>);});});})(jQuery);</script><?php
			}
			else {
			if($settings['add_link'] == 'yes'){	?>
			<a href="<?php echo esc_url($settings['link']['url']); ?>" <?php echo  esc_attr($target) . esc_attr($nofollow); ?>>
			<?php
			}
			}
		$op .='<div id="'.esc_attr($id).'" class="asvg-lotties-animation-wrapper asvg-'.esc_attr($id).' '.$classes.' '.$animation.'"  style="'.$style_atts.'" '.$asvg_opt.'></div>';

		if($settings["stroke_change"] == 'yes'){
		echo '<style>';
		echo '#'; ?><?php echo $id ?><?php echo ' path {stroke-width: ' ?><?php echo $stroke ?><?php echo ';}'?>
		<?php echo '#'; ?><?php echo $id ?><?php echo':hover path {stroke-width: '?><?php echo $stroke_hov ?><?php echo ';}'?>
		<?php echo '</style>';?>
		<?php } ?>
		<style>
		#<?php echo $id ?> path {
			transition-property: stroke-width, stroke;
			transition-duration: <?php echo esc_attr($settings['hover_transition_lottie']['size']) ?>s;
		}
		svg {
			transition-property: filter;
			transition-duration: <?php echo esc_attr($settings['hover_transition_lottie']['size']) ?>s;
			z-index: 0;
		}
		.asvg-lotties-animation-wrapper, .asvg-<?php echo $id ?> {
			transition-duration: <?php echo esc_attr($settings['hover_transition_lottie']['size']) ?>s;
		}
		</style><?php
		if($settings['add_link'] == 'yes'){
		$op .='</a>';
		}
		echo $op;
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new ASVG_upload_FREE() );